@@ -8,13 +8,14 @@ from sqlalchemy.orm import (
 from zope.sqlalchemy import ZopeTransactionExtension
 from .. import project_package, APP_NAME
 
-DBSession = project_package.models.models.DBSession
+DBSession = project_package.models.DBSession
+
 
 class RenameTables(DeclarativeMeta): 
     def __init__(cls, classname, bases, dict_): 
         if '__tablename__' in dict_: 
             cls.__tablename__ = dict_['__tablename__'] = APP_NAME + "_" + cls.__tablename__ 
-        
+
         return DeclarativeMeta.__init__(cls, classname, bases, dict_)
 
 Base = declarative_base(metaclass=RenameTables)
